import { trpc } from "../../trpc";
import {
  calendarExitPriceChartData,
  daysBetweenFrontAndBackExpiration,
  daysToFrontExpiration,
  exitToFrontExpiration,
  lookbackPeriodEnd,
  lookbackPeriodStart,
  similarCalendarPriceChartData,
  stockPriceChartData,
  strikePercentageFromUnderlyingPrice,
  strikePercentageFromUnderlyingPriceRadius,
  underlying,
} from "./state";

export const refreshStockPriceChartData = () => {
  stockPriceChartData.value = [];
  trpc.StockPriceChart.getChartData
    .query({
      underlying: underlying.value,
      lookbackPeriodStart: lookbackPeriodStart.value,
      lookbackPeriodEnd: lookbackPeriodEnd.value,
    })
    .then((getChartDataResponse) => {
      stockPriceChartData.value = getChartDataResponse;
    });
};
export const refreshSimilarCalendarPriceChartData = () => {
  similarCalendarPriceChartData.value = [];
  trpc.SimilarCalendarPriceChart.getChartData
    .query({
      underlying: underlying.value,
      daysToFrontExpiration: daysToFrontExpiration.value,
      daysBetweenFrontAndBackExpiration:
        daysBetweenFrontAndBackExpiration.value,
      strikePercentageFromUnderlyingPriceRangeMin:
        strikePercentageFromUnderlyingPrice.value -
        strikePercentageFromUnderlyingPriceRadius.value,
      strikePercentageFromUnderlyingPriceRangeMax:
        strikePercentageFromUnderlyingPrice.value +
        strikePercentageFromUnderlyingPriceRadius.value,
      lookbackPeriodStart: lookbackPeriodStart.value,
      lookbackPeriodEnd: lookbackPeriodEnd.value,
    })
    .then((getChartDataResponse) => {
      similarCalendarPriceChartData.value = getChartDataResponse;
    });
};
export const refreshcalendarExitPriceChartData = () => {
  calendarExitPriceChartData.value = [];
  trpc.CalendarExitPriceChart.getChartData
    .query({
      underlying: underlying.value,
      daysToFrontExpiration: exitToFrontExpiration.value,
      daysBetweenFrontAndBackExpiration:
        daysBetweenFrontAndBackExpiration.value,
      lookbackPeriodStart: lookbackPeriodStart.value,
      lookbackPeriodEnd: lookbackPeriodEnd.value,
    })
    .then((getChartDataResponse) => {
      calendarExitPriceChartData.value = getChartDataResponse;
    });
};
