export type Candlestick = {
  open: number;
  close: number;
  high: number;
  low: number;
};

export type Aggregate<T> = {
  key: T;
  /** UNIX time in milliseconds */
  tsStart: number;
} & Candlestick;

export type AggregateDatabase<T> = {
  getKeys: ({
    key,
    date,
  }: {
    key?: T | Partial<T>;
    date?: string;
  }) => Promise<Array<T>>;
  getAggregates: ({
    key,
    date,
  }: {
    key: T;
    date: string;
  }) => Promise<Array<Omit<Aggregate<T>, "key">>>;
  /** Since an aggregate may not exist at the specified `tsStart`, return `undefined` if it doesn't exist. */
  getAggregate: ({
    key,
    tsStart,
  }: {
    key: T;
    tsStart: number;
  }) => Promise<Omit<Aggregate<T>, "key"> | undefined>;
  getAggregatesSync?: ({
    key,
    date,
  }: {
    key: T;
    date: string;
  }) => Array<Omit<Aggregate<T>, "key">>;
  insertAggregates: (aggregates: Array<Aggregate<T>>) => Promise<void>;
  getClosingPrice: ({ key }: { key: T }) => Promise<number>;
};
