import { query } from "./lib/clickhouse.js";
import { publicProcedure, RpcType, router } from "./trpc.js";
import {
  Object as ObjectT,
  String as StringT,
  Number as NumberT,
} from "@sinclair/typebox";

/** Gets a list of symbols that have at least one option contract */
export const getAvailableUnderlyings = publicProcedure.query(async (opts) => {
  // return (
  //   await query<{ symbol: string }>(`
  //   SELECT DISTINCT(symbol) as symbol FROM option_contract_existences WHERE asOfDate = (SELECT max(asOfDate) FROM option_contract_existences)
  // `)
  // ).map(({ symbol }) => symbol);
  return ["AAPL", "AMD", "GOOGL", "MSFT", "NFLX"];
});

export const getAvailableAsOfDates = publicProcedure
  .input(RpcType(ObjectT({ underlying: StringT() })))
  .query(async (opts) => {
    const underlying = opts.input.underlying;
    return (
      await query<{ asOfDate: string }>(`
		SELECT 
			DISTINCT(asOfDate) as asOfDate 
		FROM option_contract_existences 
		WHERE symbol = '${underlying}'
		ORDER BY asOfDate
	`)
    ).map(({ asOfDate }) => asOfDate);
  });

export const getExpirationsForUnderlying = publicProcedure
  .input(
    RpcType(
      ObjectT({
        underlying: StringT({ maxLength: 5 }),
        asOfDate: StringT(),
      })
    )
  )
  .query(async (opts) => {
    const { underlying, asOfDate } = opts.input;
    return (
      await query<{ expirationDate: string }>(`
		SELECT
			DISTINCT(expirationDate) as expirationDate
		FROM option_contract_existences
		WHERE symbol = '${underlying}'
		AND asOfDate = '${asOfDate}'
		ORDER BY expirationDate
	`)
    ).map(({ expirationDate }) => expirationDate);
  });

export const getStrikesForUnderlying = publicProcedure
  .input(
    RpcType(
      ObjectT({
        underlying: StringT({ maxLength: 5 }),
        asOfDate: StringT(),
        expirationDate: StringT(),
      })
    )
  )
  .query(async (opts) => {
    const { underlying, asOfDate, expirationDate } = opts.input;
    return (
      await query<{ strike: string }>(`
		SELECT
			DISTINCT(strike) as strike
		FROM option_contract_existences
		WHERE symbol = '${underlying}'
		AND asOfDate = '${asOfDate}'
		AND expirationDate = '${expirationDate}'
		ORDER BY strike
	`)
    ).map(({ strike }) => strike);
  });

export default router({
  getAvailableUnderlyings,
  getAvailableAsOfDates,
  getExpirationsForUnderlying,
  getStrikesForUnderlying,
});
