import { query } from "./lib/clickhouse.js";
import { publicProcedure, RpcType, router } from "./trpc.js";
import {
  Object as ObjectT,
  String as StringT,
  Number as NumberT,
} from "@sinclair/typebox";

export const getChartData = publicProcedure
  .input(
    RpcType(
      ObjectT({
        underlying: StringT({ maxLength: 5 }),
        daysToFrontExpiration: NumberT(),
        daysBetweenFrontAndBackExpiration: NumberT(),
        lookbackPeriodStart: StringT({
          pattern: "[0-9]{4}-[0-9]{2}-[0-9]{2}",
        }),
        lookbackPeriodEnd: StringT({ pattern: "[0-9]{4}-[0-9]{2}-[0-9]{2}" }),
      })
    )
  )
  .query(async (opts) => {
    const {
      underlying,
      daysToFrontExpiration,
      daysBetweenFrontAndBackExpiration,
      lookbackPeriodStart,
      lookbackPeriodEnd,
    } = opts.input;
    return await query<[number, number, number]>(
      `
		 SELECT
			 FLOOR(strikePercentageFromUnderlyingPrice, 1) as x,
			 FLOOR(calendarPrice, 1) as y,
			 count(*) as n
		 FROM calendar_histories
		 WHERE symbol = '${underlying}'
		 AND daysToFrontExpiration = ${daysToFrontExpiration}
		 AND strikePercentageFromUnderlyingPrice >= -5.0
		 AND strikePercentageFromUnderlyingPrice <= 5.0
		 AND daysBetweenFrontAndBackExpiration = ${daysBetweenFrontAndBackExpiration}
		 AND tsStart >= '${lookbackPeriodStart} 00:00:00'
		 AND tsStart <= '${lookbackPeriodEnd} 00:00:00'
		 GROUP BY x, y
		 ORDER BY x ASC, y ASC
	 `,
      "JSONEachRow"
    );
  });

export default router({
  getChartData,
});
