import React, { useState, useEffect } from "react";
import { render, Box, Text, useInput, useApp } from "ink";
import TextInput from "ink-text-input";
import type { BacktestInput } from "./backtest.js";
import { backtest } from "./backtest.js";

const App = () => {
  const [step, setStep] = useState(0);
  const [input, setInput] = useState<Partial<BacktestInput>>({});
  const [result, setResult] = useState<string>("");
  const { exit } = useApp();

  const steps = [
    { prompt: "Enter symbol:", key: "symbol" },
    { prompt: "Enter start date (YYYY-MM-DD):", key: "startDate" },
    { prompt: "Enter end date (YYYY-MM-DD):", key: "endDate" },
    {
      prompt: "Enter historical probability of success (0-1, default 0.8):",
      key: "historicalProbabilityOfSuccess",
    },
    {
      prompt: "Enter initial buying power (default 2000):",
      key: "initialBuyingPower",
    },
  ];

  useInput((input, key) => {
    if (key.escape) {
      exit();
    }
  });

  useEffect(() => {
    if (step === steps.length) {
      const runBacktest = async () => {
        try {
          const backtestResult = await backtest(input as BacktestInput);
          setResult(JSON.stringify(backtestResult, null, 2));
        } catch (error) {
          setResult(`Error: ${error.message}`);
        }
      };
      runBacktest();
    }
  }, [step, input]);

  const handleSubmit = (value: string) => {
    const currentStep = steps[step];
    let parsedValue: string | number = value;

    if (
      currentStep.key === "historicalProbabilityOfSuccess" ||
      currentStep.key === "initialBuyingPower"
    ) {
      parsedValue = Number.parseFloat(value) || undefined;
    }

    setInput({ ...input, [currentStep.key]: parsedValue });
    setStep(step + 1);
  };

  if (step < steps.length) {
    return (
      <Box flexDirection="column">
        <Text>{steps[step].prompt}</Text>
        <TextInput
          value={(input[steps[step].key] as string) || ""}
          onChange={(value) =>
            setInput((prev) => ({ ...prev, [steps[step].key]: value }))
          }
          onSubmit={handleSubmit}
        />
      </Box>
    );
  }

  return (
    <Box flexDirection="column">
      <Text>Backtest Results:</Text>
      <Text>{result}</Text>
    </Box>
  );
};

render(<App />);
